@@ -22,9 +22,9 @@ subgroup <- function(x, tau.preset = NULL, byvar.glmm, ...) {
   prop <- inherits(x, "metaprop")
   rate <- inherits(x, "metarate")
   ##
-  bin.cont <- bin | cont
-  bin.inc  <- bin | inc
-  cor.prop <- cor | prop
+  bin.cont.gen <- bin | cont | gen
+  bin.inc <- bin | inc
+  cor.prop.mean <- cor | prop | mean
   
   
   sumNA <- function(x)
@@ -98,6 +98,7 @@ subgroup <- function(x, tau.preset = NULL, byvar.glmm, ...) {
                        hakn = x$hakn,
                        method.tau = x$method.tau,
                        tau.preset = tau.preset, TE.tau = x$TE.tau,
+                       n.e = x$n.e[sel], n.c = x$n.c[sel],
                        warn = x$warn,
                        control = x$control)
     ##
@@ -158,6 +159,9 @@ subgroup <- function(x, tau.preset = NULL, byvar.glmm, ...) {
                         tau.preset = tau.preset, TE.tau = x$TE.tau,
                         warn = x$warn)
     ##
+    else
+      stop("No meta-analysis object used for subgroup analysis.")
+    ##
     ##
     res.w[j,] <- c(meta1$TE.fixed,                            #  1
                    meta1$seTE.fixed,                          #  2
@@ -177,14 +181,14 @@ subgroup <- function(x, tau.preset = NULL, byvar.glmm, ...) {
                    1 / mean(1 / x$n[sel]),                    # 16
                    sum(x$w.fixed[sel]),                       # 17
                    sum(x$w.random[sel]),                      # 18
-                   if (bin.inc)  sumNA(meta1$event.e) else NA,# 19
-                   if (bin.cont) sumNA(meta1$n.e) else NA,    # 20
-                   if (bin.inc)  sumNA(meta1$event.c) else NA,# 21
-                   if (bin.cont) sumNA(meta1$n.c) else NA,    # 22
-                   if (prop)     sumNA(meta1$event) else NA,  # 23
-                   if (cor.prop) sumNA(meta1$n) else NA,      # 24
-                   if (inc)      sumNA(meta1$time.e) else NA, # 25
-                   if (inc)      sumNA(meta1$time.c) else NA, # 26
+                   if (bin.inc) sumNA(meta1$event.e) else NA, # 19
+                   if (bin.cont.gen) sumNA(meta1$n.e) else NA,# 20
+                   if (bin.inc) sumNA(meta1$event.c) else NA, # 21
+                   if (bin.cont.gen) sumNA(meta1$n.c) else NA,# 22
+                   if (prop) sumNA(meta1$event) else NA,      # 23
+                   if (cor.prop.mean) sumNA(meta1$n) else NA, # 24
+                   if (inc) sumNA(meta1$time.e) else NA,      # 25
+                   if (inc) sumNA(meta1$time.c) else NA,      # 26
                    1 / mean(1 / x$time[sel]),                 # 27
                    meta1$Rb,                                  # 28
                    meta1$lower.Rb,                            # 29
@@ -238,25 +242,20 @@ subgroup <- function(x, tau.preset = NULL, byvar.glmm, ...) {
     if (prop) {
       mod <- as.call(~ byvar.glmm - 1)
       ##
-      glmm.fixed <- metafor::rma.glmm(xi = x$event,
-                                      ni = x$n,
-                                      mods = mod,
-                                      method = "FE",
-                                      test = ifelse(x$hakn, "t", "z"),
-                                      level = 100 * x$level.comb,
-                                      measure = "PLO",
-                                      intercept = FALSE,
-                                      ...)
+      glmm.fixed <- rma.glmm(xi = x$event, ni = x$n,
+                             mods = mod,
+                             method = "FE", test = ifelse(x$hakn, "t", "z"),
+                             level = 100 * x$level.comb,
+                             measure = "PLO", intercept = FALSE,
+                             ...)
       ##
-      glmm.random <- metafor::rma.glmm(xi = x$event,
-                                       ni = x$n,
-                                       mods = mod,
-                                       method = x$method.tau,
-                                       test = ifelse(x$hakn, "t", "z"),
-                                       level = 100 * x$level.comb,
-                                       measure = "PLO",
-                                       intercept = FALSE,
-                                       ...)
+      glmm.random <- rma.glmm(xi = x$event, ni = x$n,
+                              mods = mod,
+                              method = x$method.tau,
+                              test = ifelse(x$hakn, "t", "z"),
+                              level = 100 * x$level.comb,
+                              measure = "PLO", intercept = FALSE,
+                              ...)
     }
     ##
     TE.fixed.w   <- as.numeric(glmm.fixed$b)
